import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_tokens/tokens/senior_spacing.dart';

class SeniorNotification {
  final String title;
  final String body;
  final String footer;

  const SeniorNotification({
    required this.title,
    required this.body,
    required this.footer,
  });
}

class SeniorNotificationList extends StatelessWidget {
  final String title;
  final List<SeniorNotification> notifications;
  final Function(int)? onNotificationTap;
  final String? actionButtonLabel;
  final Function()? onTapActionButton;
  final bool isLoading;
  final String? loadButtonLabel;
  final Function()? onLoad;

  SeniorNotificationList({
    Key? key,
    required this.title,
    required this.notifications,
    this.onNotificationTap,
    this.actionButtonLabel,
    this.onTapActionButton,
    this.isLoading = false,
    this.loadButtonLabel,
    this.onLoad,
  }) : super(key: key);
  
  Widget _buildNotification(SeniorNotification notification) {
    return InkWell(
      child: Container(
        padding: EdgeInsets.symmetric(
          horizontal: 40.0,
          vertical: 16.0,
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                bottom: SeniorSpacing.xsmall,
              ),
              child: Text(
                notification.title,
                style: SeniorTypography.text(
                  color: SeniorColors.pureBlack,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(
                bottom: SeniorSpacing.xsmall,
              ),
              child: Text(
                notification.body,
                style: SeniorTypography.body(
                  color: SeniorColors.neutralColor800,
                ),
              ),
            ),
            Text(
              notification.footer,
              style: SeniorTypography.helper(
                color: SeniorColors.neutralColor500,
              ),
            ),
          ],
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Column(
        children: [
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: SeniorSpacing.xmedium,
                vertical: SeniorSpacing.small,
              ),
              child: Text(
                title,
                style: SeniorTypography.body(
                  color: SeniorColors.neutralColor800,
                ),
              ),
            ),
          ),
          Expanded(
            child: ListView.builder(
              scrollDirection: Axis.vertical,
              shrinkWrap: true,
              itemCount: notifications.length + 1,
              itemBuilder: (context, index) {
                if (index == notifications.length) {
                  return onLoad != null && loadButtonLabel != null && !isLoading
                      ? Padding(
                          padding: const EdgeInsets.all(16.0),
                          child: SeniorButton(
                            label: loadButtonLabel!,
                            type: SeniorButtonType.ghost,
                            size: SeniorButtonSize.small,
                            onPressed: onLoad!,
                          ),
                        )
                      : SizedBox.shrink();
                }
                return InkWell(
                  onTap: onNotificationTap != null
                      ? () => onNotificationTap!(index)
                      : null,
                  child: _buildNotification(notifications[index]),
                );
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(
              SeniorSpacing.big,
            ),
            child: Column(
              children: [
                isLoading
                    ? Padding(
                        padding: const EdgeInsets.only(
                            bottom: SeniorSpacing.xmedium),
                        child: SeniorLoading(),
                      )
                    : SizedBox.shrink(),
                onTapActionButton != null && actionButtonLabel != null
                    ? SeniorButton(
                        label: actionButtonLabel!,
                        type: SeniorButtonType.secondary,
                        onPressed: onTapActionButton!,
                      )
                    : SizedBox.shrink(),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
